**SYMBOLICA AI, INC. CONTRIBUTION LICENSE AGREEMENT**

This Contribution License Agreement (the “**CLA**”) is between the individual set forth in the signature block (“**You**”) and Symbolica AI, Inc., (“**Symbolica**”), effective as of the date of Your signature and sets forth the terms pursuant to which You provides Contributions to Symbolica. 

You accept and agree to the following terms and conditions for Your present and future Contributions submitted to Symbolica. In return, Symbolica will not use Your Contributions in a way that is contrary to Symbolica’s business objectives.  Except for the license granted herein to Symbolica and recipients of software distributed by Symbolica, You reserve all right, title, and interest in and to Your Contributions. 

1. Definitions. “**Contribution**” means any original work of authorship, including any modifications or additions to an existing work, that You intentionally submit to Symbolica for inclusion in, or documentation of, any of the products owned or managed by Symbolica (the “**Work**”). “**Submit**” means any form of electronic, verbal, or written communication sent to Symbolica or its representatives, including but not limited to communication on electronic mailing lists, source code control systems, and issue tracking systems that are managed by, or on behalf of, Symbolica for the purpose of discussing and improving the Work, but excluding communication that is conspicuously marked or otherwise designated in writing by You as “Not a Contribution.” 

2. Copyright License. Subject to the terms and conditions of this CLA, You hereby grant to Symbolica and to recipients of software distributed by Symbolica a perpetual, worldwide, non-exclusive, no-charge, royalty-free, irrevocable copyright license to reproduce, prepare derivative works of, publicly display, publicly perform, sublicense, and distribute Your Contributions and such derivative works.   
     
3. Patent License. Subject to the terms and conditions of this CLA, You hereby grant to Symbolica and to recipients of software distributed by Symbolica a perpetual, worldwide, non-exclusive, no-charge, royalty-free, irrevocable (except as stated in this section) patent license to make, have made, use, offer to sell, sell, import, and otherwise transfer the Work, where such license applies only to those patent claims licensable by You that are necessarily infringed by Your Contribution(s) alone or by combination of Your Contribution(s) with the Work to which such Contribution(s) was submitted. If any entity institutes patent litigation against You or any other entity (including a cross-claim or counterclaim in a lawsuit) alleging that Your Contribution, or the Work to which You have contributed, constitutes direct or contributory patent infringement, then any patent licenses granted to that entity under this CLA for that Contribution or Work will terminate as of the date such litigation is filed.   
     
4. Representations and Warranties. You represent and warrant to Symbolica that:   
     
   1. You are legally entitled to grant the above license, and if Your employer(s) has rights to intellectual property that You create that includes Your Contributions, then You represent and warrant that You have received permission to make Contributions on behalf of that employer, that Your employer has waived such rights for Your Contributions to Symbolica, or that Your employer has executed a separate CLA with Symbolica;   
        
   2. Each of Your Contributions is Your original creation (see section 6 for submissions on behalf of others); and

   

   3. Your Contribution submissions include complete details of any third-party license or other restriction (including, but not limited to, related patents and trademarks) of which You are personally aware and which are associated with any part of Your Contributions. 

   

5. Support; Disclaimer. You are not expected to provide support for Your Contributions, except to the extent You desire to do so. You may provide support for free, for a fee, or not at all. Unless required by applicable law or agreed to in writing, You provide Your Contributions on an “AS IS” BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied, including, without limitation, any warranties or conditions of TITLE, NON- INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A PARTICULAR PURPOSE. 

6. Third Party Works. If You wish to submit work that is not Your original creation, then You may submit it to Symbolica separately from any Contribution, identifying the complete details of its source and of any license or other restriction (including, but not limited to, related patents, trademarks, and license agreements) of which You are personally aware, and conspicuously marking the work as “Submitted on behalf of a third-party: \[named here\]”.   
     
7. You agree to notify Symbolica of any facts or circumstances of which You become aware that would make Your representations in this CLA inaccurate in any respect.  
     
8. General. This CLA is the entire understanding and agreement with respect to the subject matter hereof, and supersedes any and all prior or contemporaneous representations, understandings, and agreements, between the parties regarding same. If any part of this CLA is found to be unenforceable, the remaining portions of this CLA will remain in full force and effect. No modification of or amendment to this CLA, nor any waiver of any rights under this CLA, will be effective unless in writing signed by the party to be charged, and the waiver of any breach or default will not constitute a waiver of any other right under this CLA or any subsequent breach or default.  Nothing in this CLA creates and the parties do not intend to create, any partnership or joint venture between themselves. Either party may freely assign this CLA. This CLA is binding upon and will inure to the benefit of a party’s successors and permitted assigns. This CLA will be governed by the laws of the State of New York.  Exclusive jurisdiction of any and all disputes hereunder will be in the state and federal courts in New York, New York. This CLA may be executed in counterparts with the same effect as if all signatories had signed the same document.

| YOUR NAME:\_\_\_\_\_\_\_\_\_\_\_\_\_\_\_\_\_\_\_\_\_\_\_\_\_ | SYMBOLICA AI, INC. |
| :---- | :---- |
| BY: | BY:  |
| DATE: | DATE: |
| EMAIL ADDRESS: |  |

